@@ -1,12 +1,12 @@
-from typing import List, Union
+from typing import List, Optional
 from concurrent.futures import ProcessPoolExecutor, TimeoutError
 
-from .errors import YumNotImplemented, YumUnavailable, YumTimeout
-from .ticket import Ticket
+from .errors import YumError, YumNotImplemented, YumUnavailable, YumTimeout
+from .ticket import Ticket, Feedback
 from .worker import Worker
 
 
-def _handle(worker: Worker, ticket: Ticket) -> Union[Ticket, None]:
+def _handle(worker: Worker, ticket: Ticket) -> Optional[Feedback]:
     with worker as w:
         return w.doing(ticket)
 
@@ -34,14 +34,24 @@ class Manager(object):
 
         return result
 
-    def perform(self, ticket: Ticket, timeout: int = 15) -> Union[Ticket, None]:
-        worker = self.capable(ticket.code)
+    def perform(self, ticket: Ticket, timeout: int = 15) -> Optional[Feedback]:
+        err_result = Feedback(ticket, 500)
 
-        fr = Manager.executor.submit(_handle, worker, ticket)
         try:
+            worker = self.capable(ticket.code)
+            fr = Manager.executor.submit(_handle, worker, ticket)
             return fr.result(timeout)
+        except YumError as e:
+            err_result.status = e.code
+            err_result.put("errors", e.reason)
         except TimeoutError:
-            raise YumTimeout
+            yt = YumTimeout()
+            err_result.status = yt.code
+            err_result.put("errors", yt.reason)
+        except Exception as ex:
+            err_result.put("errors", str(ex))
+
+        return err_result
 
     def off_duty(self):
         Manager.executor.shutdown()
