@@ -52,7 +52,11 @@ def _decode(obj, msg: str) -> None:
         obj.id = t.get("id")
         obj.code = t.get("code")
         obj.birth_time = t.get("birth_time")
-        obj.body = t.get("body")
+        b = t.get("body")
+        if isinstance(b, list):
+            obj.body = b[0]
+        elif isinstance(b, dict):
+            obj.body = b
         obj.status = t.get("status")
 
     if isinstance(obj, Feedback):
@@ -70,6 +74,7 @@ class Ticket(object):
 
     def __repr__(self) -> str:
         j = self.__dict__.copy()
+        j["body"] = self.body.copy()
         j["birth_time"] = self.birth_time.strftime("%Y-%m-%d %H:%M:%S")
         return json.dumps(j)
 
